summaryrefslogtreecommitdiff
path: root/source3/rpc_server
diff options
context:
space:
mode:
authorAndrew Bartlett <abartlet@samba.org>2002-07-06 05:08:35 +0000
committerAndrew Bartlett <abartlet@samba.org>2002-07-06 05:08:35 +0000
commit48316a8c0e6b0ce6d4db966d319517a844194fce (patch)
tree00024ba939f4a45bbeb4d384bd16b2aec78a964d /source3/rpc_server
parenta7a6da49285328e70c22df03faee306311c14b83 (diff)
downloadsamba-48316a8c0e6b0ce6d4db966d319517a844194fce.tar.gz
samba-48316a8c0e6b0ce6d4db966d319517a844194fce.tar.bz2
samba-48316a8c0e6b0ce6d4db966d319517a844194fce.zip
Copy the NT_TOKEN to the pipe, so the SAMR can use it for access control.
Andrew Bartlett (This used to be commit 685a205445f5505c105ea421712c4b0468bbc127)
Diffstat (limited to 'source3/rpc_server')
-rw-r--r--source3/rpc_server/srv_pipe_hnd.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/source3/rpc_server/srv_pipe_hnd.c b/source3/rpc_server/srv_pipe_hnd.c
index d4d45c230c..cc6e4b95f9 100644
--- a/source3/rpc_server/srv_pipe_hnd.c
+++ b/source3/rpc_server/srv_pipe_hnd.c
@@ -344,9 +344,11 @@ static void *make_internal_rpc_pipe_p(char *pipe_name,
p->pipe_user.uid = (uid_t)-1;
p->pipe_user.gid = (gid_t)-1;
- /* Store the session key */
- if (vuser)
+ /* Store the session key and NT_TOKEN */
+ if (vuser) {
memcpy(p->session_key, vuser->session_key, sizeof(p->session_key));
+ p->pipe_user.nt_user_token = dup_nt_token(vuser->nt_user_token);
+ }
/*
* Initialize the incoming RPC struct.